@@ -23,10 +23,10 @@ import tarfile
 import tempfile
 import time
 from collections import Counter, namedtuple
-from collections.abc import AsyncGenerator, Generator
+from collections.abc import AsyncGenerator, Callable, Generator
 from datetime import datetime
 from functools import partial
-from typing import Any, Callable, cast
+from typing import Any, cast
 
 from asgiref.sync import sync_to_async
 from botocore.exceptions import ClientError
@@ -750,7 +750,7 @@ class SageMakerHook(AwsBaseHook):
 
             if status in self.failed_states:
                 raise AirflowException(f"SageMaker resource failed because {response['FailureReason']}")
-            elif status not in non_terminal_states:
+            if status not in non_terminal_states:
                 break
 
             if max_ingestion_time and sec > max_ingestion_time:
@@ -1010,8 +1010,7 @@ class SageMakerHook(AwsBaseHook):
             if "NextToken" not in response or (max_results is not None and len(results) == max_results):
                 # Return when there are no results left (no NextToken) or when we've reached max_results.
                 return results
-            else:
-                next_token = response["NextToken"]
+            next_token = response["NextToken"]
 
     @staticmethod
     def _name_matches_pattern(
@@ -1172,9 +1171,8 @@ class SageMakerHook(AwsBaseHook):
                     ):
                         self.log.warning("Cannot stop pipeline execution, as it was not running: %s", ce)
                         break
-                    else:
-                        self.log.error(ce)
-                        raise
+                    self.log.error(ce)
+                    raise
             else:
                 break
 
@@ -1214,9 +1212,8 @@ class SageMakerHook(AwsBaseHook):
                 # log msg only so it doesn't look like an error
                 self.log.info("%s", e.response["Error"]["Message"])
                 return False
-            else:
-                self.log.error("Error when trying to create Model Package Group: %s", e)
-                raise
+            self.log.error("Error when trying to create Model Package Group: %s", e)
+            raise
 
     def _describe_auto_ml_job(self, job_name: str):
         res = self.conn.describe_auto_ml_job(AutoMLJobName=job_name)
